@@ -35,6 +35,7 @@ fn main() {
     // Only rerun if files in the vendor/ directory change.
     println!("cargo:rerun-if-changed=vendor");
 
+    // TODO: build these in parallel.
     build("tree-sitter-clojure", "vendor/tree-sitter-clojure-src", &[]);
     build(
         "tree-sitter-css",
@@ -42,6 +43,11 @@ fn main() {
         &["scanner.c"],
     );
     build("tree-sitter-elisp", "vendor/tree-sitter-elisp-src", &[]);
+    build(
+        "tree-sitter-elixir",
+        "vendor/tree-sitter-elixir-src",
+        &["scanner.cc"],
+    );
     build("tree-sitter-go", "vendor/tree-sitter-go-src", &[]);
     build("tree-sitter-java", "vendor/tree-sitter-java-src", &[]);
     build(
@@ -70,4 +76,14 @@ fn main() {
         "vendor/tree-sitter-rust-src",
         &["scanner.c"],
     );
+    build(
+        "tree-sitter-tsx",
+        "vendor/tree-sitter-typescript-src/tsx/src",
+        &["scanner.c"],
+    );
+    build(
+        "tree-sitter-typescript",
+        "vendor/tree-sitter-typescript-src/typescript/src",
+        &["scanner.c"],
+    );
 }
