@@ -1,3 +1,5 @@
+//! A fallback "parser" for plain text.
+
 use typed_arena::Arena;
 
 use crate::{positions::SingleLineSpan, syntax::Syntax};
@@ -7,8 +9,15 @@ use crate::{positions::SingleLineSpan, syntax::Syntax};
 /// This is a fallback for files that we don't know how to parse.
 pub fn parse<'a>(arena: &'a Arena<Syntax<'a>>, s: &str) -> Vec<&'a Syntax<'a>> {
     let mut res = vec![];
+    // TODO: This scales poorly to large files (e.g. parser.c
+    // changes). Consider grouping Syntax items into lists when we
+    // encounter blank lines.
     for (i, line) in s.lines().enumerate() {
-        res.push(Syntax::new_atom(
+        // Mark each line as a comment atom, so we get word-level diffs.
+        // TODO: this is very hot on large files, such as parser.c,
+        // because we spend ~65% of execution time computing
+        // levenshtein distance.
+        res.push(Syntax::new_comment(
             arena,
             vec![SingleLineSpan {
                 line: i.into(),
@@ -35,7 +44,7 @@ mod tests {
         assert_syntaxes(
             &parse(&arena, "foo\nbar"),
             &[
-                Syntax::new_atom(
+                Syntax::new_comment(
                     &arena,
                     vec![SingleLineSpan {
                         line: 0.into(),
@@ -44,7 +53,7 @@ mod tests {
                     }],
                     "foo",
                 ),
-                Syntax::new_atom(
+                Syntax::new_comment(
                     &arena,
                     vec![SingleLineSpan {
                         line: 1.into(),
