@@ -3,16 +3,19 @@
 #![allow(clippy::mutable_key_type)] // Hash for Syntax doesn't use mutable fields.
 
 use itertools::{EitherOrBoth, Itertools};
-use std::cell::Cell;
-use std::cmp::min;
-use std::collections::hash_map::DefaultHasher;
-use std::collections::HashMap;
-use std::hash::{Hash, Hasher};
-use std::{env, fmt};
+use std::{
+    cell::Cell,
+    cmp::min,
+    collections::{hash_map::DefaultHasher, HashMap},
+    env, fmt,
+    hash::{Hash, Hasher},
+};
 use typed_arena::Arena;
 
-use crate::lines::{LineGroup, LineNumber, NewlinePositions};
-use crate::positions::SingleLineSpan;
+use crate::{
+    lines::{LineGroup, LineNumber, NewlinePositions},
+    positions::SingleLineSpan,
+};
 use ChangeKind::*;
 use Syntax::*;
 
@@ -43,6 +46,7 @@ pub struct SyntaxInfo<'a> {
     pub pos_content_hash: u64,
     pub next: Cell<Option<&'a Syntax<'a>>>,
     pub prev: Cell<Option<&'a Syntax<'a>>>,
+    pub prev_is_contiguous: Cell<bool>,
     pub change: Cell<Option<ChangeKind<'a>>>,
     pub num_ancestors: Cell<u64>,
     pub unique_id: Cell<u64>,
@@ -54,6 +58,7 @@ impl<'a> SyntaxInfo<'a> {
             pos_content_hash,
             next: Cell::new(None),
             prev: Cell::new(None),
+            prev_is_contiguous: Cell::new(false),
             change: Cell::new(None),
             num_ancestors: Cell::new(0),
             unique_id: Cell::new(0),
@@ -227,8 +232,7 @@ impl<'a> Syntax<'a> {
 
     pub fn info(&self) -> &SyntaxInfo<'a> {
         match self {
-            List { info, .. } => info,
-            Atom { info, .. } => info,
+            List { info, .. } | Atom { info, .. } => info,
         }
     }
 
@@ -237,26 +241,7 @@ impl<'a> Syntax<'a> {
     }
 
     pub fn prev_is_contiguous(&self) -> bool {
-        if let Some(prev) = self.info().prev.get() {
-            match prev {
-                List {
-                    open_position,
-                    close_position,
-                    ..
-                } => {
-                    let prev_is_parent = prev.num_ancestors() < self.num_ancestors();
-                    if prev_is_parent {
-                        open_position.last().map(|p| p.line) == self.first_line()
-                    } else {
-                        // predecessor node at the same level.
-                        close_position.last().map(|p| p.line) == self.first_line()
-                    }
-                }
-                Atom { .. } => prev.last_line() == self.first_line(),
-            }
-        } else {
-            false
-        }
+        self.info().prev_is_contiguous.get()
     }
 
     pub fn id(&self) -> u64 {
@@ -427,7 +412,7 @@ pub fn init_info<'a>(lhs_roots: &[&'a Syntax<'a>], rhs_roots: &[&'a Syntax<'a>])
     init_info_single(rhs_roots, next_id);
 }
 
-/// Initialise all the fields in SyntaxInfo.
+/// Initialise all the fields in `SyntaxInfo`.
 ///
 /// Return the next unique ID available, so we can ensure LHS and RHS
 /// have different IDs.
@@ -435,6 +420,7 @@ pub fn init_info_single<'a>(roots: &[&'a Syntax<'a>], first_id: u64) -> u64 {
     set_next(roots, None);
     set_prev(roots, None);
     set_num_ancestors(roots, 0);
+    set_prev_is_contiguous(roots);
     set_unique_id(roots, first_id)
 }
 
@@ -489,6 +475,35 @@ fn set_num_ancestors<'a>(nodes: &[&Syntax<'a>], num_ancestors: u64) {
     }
 }
 
+fn set_prev_is_contiguous<'a>(roots: &[&Syntax<'a>]) {
+    for node in roots {
+        let is_contiguous = if let Some(prev) = node.info().prev.get() {
+            match prev {
+                List {
+                    open_position,
+                    close_position,
+                    ..
+                } => {
+                    let prev_is_parent = prev.num_ancestors() < node.num_ancestors();
+                    if prev_is_parent {
+                        open_position.last().map(|p| p.line) == node.first_line()
+                    } else {
+                        // predecessor node at the same level.
+                        close_position.last().map(|p| p.line) == node.first_line()
+                    }
+                }
+                Atom { .. } => prev.last_line() == node.first_line(),
+            }
+        } else {
+            false
+        };
+        node.info().prev_is_contiguous.set(is_contiguous);
+        if let List { children, .. } = node {
+            set_prev_is_contiguous(children);
+        }
+    }
+}
+
 impl<'a> PartialEq for Syntax<'a> {
     fn eq(&self, other: &Self) -> bool {
         self.equal_pos(other) && self.equal_content(other)
@@ -516,10 +531,7 @@ pub enum MatchKind {
 
 impl MatchKind {
     pub fn is_unchanged(&self) -> bool {
-        match self {
-            MatchKind::Unchanged { .. } => true,
-            _ => false,
-        }
+        matches!(self, MatchKind::Unchanged { .. })
     }
 }
 
