@@ -1,3 +1,5 @@
+//! Parse code with tree-sitter language implementations.
+
 use std::{borrow::Borrow, collections::HashSet, ffi::OsStr};
 
 use tree_sitter::{Language, Parser, TreeCursor};
@@ -26,6 +28,7 @@ extern "C" {
     fn tree_sitter_clojure() -> Language;
     fn tree_sitter_css() -> Language;
     fn tree_sitter_elisp() -> Language;
+    fn tree_sitter_elixir() -> Language;
     fn tree_sitter_go() -> Language;
     fn tree_sitter_java() -> Language;
     fn tree_sitter_javascript() -> Language;
@@ -34,22 +37,26 @@ extern "C" {
     fn tree_sitter_ocaml_interface() -> Language;
     fn tree_sitter_python() -> Language;
     fn tree_sitter_rust() -> Language;
+    fn tree_sitter_tsx() -> Language;
+    fn tree_sitter_typescript() -> Language;
 }
 
 pub fn from_extension(extension: &OsStr) -> Option<TreeSitterConfig> {
     // TODO: find a nice way to extract name and extension information
     // from the package.json in these parsers.
     match extension.to_string_lossy().borrow() {
-        "clj" => Some(TreeSitterConfig {
-            name: "Clojure",
-            language: unsafe { tree_sitter_clojure() },
-            atom_nodes: (vec![]).into_iter().collect(),
-            open_delimiter_tokens: (vec!["{", "(", "["]).into_iter().collect(),
-        }),
+        "bb" | "boot" | "clj" | "cljc" | "clje" | "cljs" | "cljx" | "edn" | "joke" | "joker" => {
+            Some(TreeSitterConfig {
+                name: "Clojure",
+                language: unsafe { tree_sitter_clojure() },
+                atom_nodes: (vec![]).into_iter().collect(),
+                open_delimiter_tokens: (vec!["{", "(", "["]).into_iter().collect(),
+            })
+        }
         "css" => Some(TreeSitterConfig {
             name: "CSS",
             language: unsafe { tree_sitter_css() },
-            atom_nodes: (vec![]).into_iter().collect(),
+            atom_nodes: (vec!["integer_value"]).into_iter().collect(),
             open_delimiter_tokens: (vec!["{", "("]).into_iter().collect(),
         }),
         "el" => Some(TreeSitterConfig {
@@ -58,6 +65,12 @@ pub fn from_extension(extension: &OsStr) -> Option<TreeSitterConfig> {
             atom_nodes: (vec![]).into_iter().collect(),
             open_delimiter_tokens: (vec!["{", "(", "["]).into_iter().collect(),
         }),
+        "ex" | "exs" => Some(TreeSitterConfig {
+            name: "Elixir",
+            language: unsafe { tree_sitter_elixir() },
+            atom_nodes: (vec!["string", "heredoc"]).into_iter().collect(),
+            open_delimiter_tokens: (vec!["(", "{", "do"]).into_iter().collect(),
+        }),
         "go" => Some(TreeSitterConfig {
             name: "Go",
             language: unsafe { tree_sitter_go() },
@@ -115,7 +128,19 @@ pub fn from_extension(extension: &OsStr) -> Option<TreeSitterConfig> {
             atom_nodes: (vec!["char_literal", "string_literal"])
                 .into_iter()
                 .collect(),
-            open_delimiter_tokens: (vec!["{", "("]).into_iter().collect(),
+            open_delimiter_tokens: (vec!["{", "(", "[", "|"]).into_iter().collect(),
+        }),
+        "ts" => Some(TreeSitterConfig {
+            name: "TypeScript",
+            language: unsafe { tree_sitter_typescript() },
+            atom_nodes: (vec!["string", "template_string"]).into_iter().collect(),
+            open_delimiter_tokens: (vec!["{", "(", "[", "<"]).into_iter().collect(),
+        }),
+        "tsx" => Some(TreeSitterConfig {
+            name: "TypeScript TSX",
+            language: unsafe { tree_sitter_tsx() },
+            atom_nodes: (vec!["string", "template_string"]).into_iter().collect(),
+            open_delimiter_tokens: (vec!["{", "(", "[", "<"]).into_iter().collect(),
         }),
         _ => None,
     }
@@ -131,7 +156,7 @@ pub fn parse_to_tree(src: &str, config: &TreeSitterConfig) -> tree_sitter::Tree
     parser.parse(src, None).unwrap()
 }
 
-pub fn print_tree(tree: tree_sitter::Tree) {
+pub fn print_tree(tree: &tree_sitter::Tree) {
     let mut cursor = tree.walk();
     print_cursor(&mut cursor, 0);
 }
